
; Monitorprogramm fuer CPD5

		TITLE	CPD5DEF

		.Z80



; **********************************************************
;         Vereinbarungsteil fuer CP/M 2.2
; **********************************************************

STACK		EQU	0FE80H

RAMSTART	EQU	0F000H

TPA		EQU	0100H

;CBIOS fuer CP/M 2.2
;
BIOSBASE	EQU	0F000H
BIOSLEN		EQU	1000H		; 4096 Byte
;
BDOSBASE    	EQU	0E200H
BDOSLEN		EQU	0E00H		; 3584 Byte = 28 * 128 		
;
CCPBASE     	EQU	0DA00H	
CCPLEN		EQU	0800H		; 2048 Byte
;
EEROMCCP	EQU	0100H
EEPROMBDOS	EQU	EEROMCCP+CCPLEN	; 0900H

;
USERLW		EQU	4	;Laufwerksregister
IOBYTE		EQU	3	;Intel I/O-Byte
;
SBDOS		EQU	BDOSBASE+6
SCCP		EQU	CCPBASE+03H



; **********************************************************
;         Vereinbarungsteil fuer den Bus-Controller
; **********************************************************


; Befehlscode fuer Z80CALL
BC_CONIN	EQU	1	; Console In
BC_CONST	EQU	2	; Console Status
BC_CONOUT	EQU	3	; Console Out


; **********************************************************
;         Vereinbarungsteil fuer die Hardware
; **********************************************************



FRQ		EQU	6			; Frequenz in MHz

	; 
	;---Kanaladressen---

; A0 = CONTSEL,  A1 = PORTSEL,  A2 = /CE-PIO1,  A3 = /CE-PIO2

PIO1AD		EQU     11111000B		;PIO 1 A Daten
PIO1AC		EQU     11111001B		;PIO 1 A Kommandos

PIO1BD		EQU     11111010B		;PIO 1 B Daten
PIO1BC		EQU     11111011B		;PIO 1 B Kommandos

PIO2AD		EQU     11110100B		;PIO 2 A Daten
PIO2AC		EQU     11110101B		;PIO 2 A Kommandos

PIO2BD		EQU     11110110B		;PIO 2 B Daten
PIO2BC		EQU     11110111B		;PIO 2 B Kommandos


; --------------------------------------------
;
; Funktionale Bezeichnung der Ports
;
D_SYS_PORT	EQU	PIO1AD
C_SYS_PORT	EQU	PIO1AC
;
D_ITP2_CON1	EQU	PIO1BD
C_ITP2_CON1	EQU	PIO1BC
;
D_ITP2_CON2	EQU	PIO2AD
C_ITP2_CON2	EQU	PIO2AC
;
D_ITP2_CON3	EQU	PIO2BD
C_ITP2_CON3	EQU	PIO2BC
;


; --------------------------------------------
;
; Bitmaske - alles Eingaenge
BITMSKAE	EQU	11111111B
; Bitmaske - alles Ausgaenge
BITMSKAA	EQU	00000000B



; ============================================
;
;   Kommandowerte der PIOs
;
; ============================================
;
;
; PIO 1 - Port A - Initialwert der Kommandos
;
; A0 = /Z80CALL  = 0 = Low aktiv  (Ausgang)
; A1 = /Z80AK    = 1 =            (Eingang)
; A2 = /Z80WA    = 0 = Low aktiv  (Ausgang)
; A3 = Z80LEDRT  = 0 = High aktiv (Ausgang)
; A4 = N.N.
; A5 = N.N.
; A6 = N.N.
; A7 = N.N.
;
; Ausgang=0 / Eingang = 1  
;                       EEEEAAEA
C_SYS_IW	EQU	11110010B	; Initialwert-Kommandos Systemport

; --------------------------------------------
;
; PIO 1 - Port B - Initialwert der Kommandos
;
; Bitmaske Port B - Initialisierung
; B0 = D0     = 1 - Eingang
; B1 = D1     = 1 - Eingang
; B2 = D2     = 1 - Eingang
; B3 = D3     = 1 - Eingang 
; B4 = DDWR   = 0 - Ausgang
; B5 = DDAC   = 1 - Eingang
; B6 = SDEN   = 1 - Eingang
; B7 = SRAC   = 1 - Eingang 

C_ITP2_IW	EQU 	11101111B	; Initialwert-Kommandos ITP2

; --------------------------------------------
;
; ITP2 Kommandos - Read-Modus
;
; Bitmaske Port B - Initialisierung
; B0 = D0     = 1 - Eingang
; B1 = D1     = 1 - Eingang
; B2 = D2     = 1 - Eingang
; B3 = D3     = 1 - Eingang
; B4 = DDWR   = 0 - Ausgang
; B5 = DDAC   = 1 - Eingang
; B6 = SDEN   = 1 - Eingang
; B7 = SRAC   = 0 - Ausgang 

C_ITP2_RD	EQU 	01101111B	; Read-Kommando ITP2	 

; --------------------------------------------
;
; ITP2 Kommandos - Write-Modus
;
; Bitmaske Port B - Initialisierung
; B0 = D0     = 0 - Ausgang
; B1 = D1     = 0 - Ausgang
; B2 = D2     = 0 - Ausgang
; B3 = D3     = 0 - Ausgang
; B4 = DDWR   = 0 - Ausgang
; B5 = DDAC   = 1 - Eingang
; B6 = SDEN   = 0 - Ausgang
; B7 = SRAC   = 1 - Eingang 

C_ITP2_WR	EQU 	10100000B	; Write-Kommando ITP2	




; ============================================
;
;   Datenwerte der PIOs
;
; ============================================
;
; PIO 1 - Port A - Initialwert der Daten des Ausgaberegisters
;
; A0 = /Z80CALL  = 1 = Low aktiv  (Ausgang)
; A1 = /Z80AK    = 0 = Low aktiv  (Eingang)
; A2 = /Z80WA    = 1 = Low aktiv  (Ausgang)
; A3 = Z80LEDRT  = 0 = High aktiv (Ausgang)
; A4 = N.N.
; A5 = N.N.
; A6 = N.N.
; A7 = N.N.
;                            
D_SYS_IW		EQU 	00000111B	; Initialwert-Daten Systemport


BIT_Z80CALL	EQU	0
BIT_Z80AK	EQU	1
BIT_Z80WA	EQU	2
BIT_LED_RT	EQU	3


; --------------------------------------------
;
; PIO 1 - Port B - Initialwert der Daten des Ausgaberegisters
;
; B0 = D0     = X = (Eingang)
; B1 = D1     = X = (Eingang)
; B2 = D2     = X = (Eingang)
; B3 = D3     = X = (Eingang)
; B4 = DDWR   = 1 = (Ausgang) High wie Widerstand
; B5 = DDAC   = 1 = (Eingang)
; B6 = SDEN   = 0 = (Eingang) SDEN inaktiv
; B7 = SRAC   = 0 = (Eingang) 

D_ITP2_IW	EQU 	00110000B	; Initialwert-Daten ITP2


BIT_ID0		EQU	0
BIT_ID1		EQU	1
BIT_ID2		EQU	2
BIT_ID3		EQU	3

BIT_DDWR	EQU	4
BIT_DDAC	EQU	5
BIT_SDEN	EQU	6
BIT_SRAC	EQU	7





; ============================================
;
;   Konstantentabellen fuer BIOS
;
; ============================================
;
;
RE_CONST	EQU	1		; Code fuer RECEIVE CONST 
RE_CONIN	EQU	2		; Code fuer RECEIVE CONIN 
SE_CONOUT	EQU	3		; Code fuer SEND CONOUT
RE_SECNT	EQU	4		; Code fuer RECEIVE SECTOR COUNT
RE_SECTOR	EQU	5		; Code fuer RECEIVE SECTOR
RE_RD_ISEC	EQU	6		; Code fuer RECEIVE READ IMAGE SECTOR
SE_WR_ISEC	EQU	7		; Code fuer SEND WRITE IMAGE SECTOR
SE_STD		EQU	8		; Code fuer SEND SECTOR, TRACK, DRIVE
SE_LIST		EQU	9		; Code fuer SEND LIST
RE_ERROR_CODE	EQU	10		; Code fuer RECEIVE ERROR CODE
RE_SAVE_RAM2FL	EQU	11		; Code fuer RECEIVE SAVE RAM-Floppy (RAM in FLASH brennen)
RE_COPY_FL2RAM	EQU	12		; Code fuer RECEIVE COPY RAM-Floppy (FLASH in RAM copieren)
SE_SECNT	EQU	14		; Code fuer SEND SECTOR COUNT

WHO_ARE_YOU	EQU	20		; Code fuer Abfrage der Funktionalitaet
					; des angeschlossenen Geraetes

; ============================================
;

DEVCODE_PC_CPM_EMU   EQU	2	; Code fuer PC-CP/M-Emulator
DEVCODE_KEYBOARD     EQU	3	; Code fuer Tastatur
DEVCODE_DISPLAY      EQU	4	; Code fuer LCD-Display
DEVCODE_RAMFLOPPY    EQU	5	; Code fuer RAM-Floppy
DEVCODE_CONINOUT     EQU        6       ; Code fuer Tastatur und Display

; ============================================
;







; ============================================
;


	;Vereinbarungsteil ROM/RAM

; ROM von 00000H bis 07FFFH
; RAM von 08000H bis 0FFFFH

; Schnittstelle zwischen Z80 und BC
; Achtung - Anne Adressen sind absolut und muessen so bleiben
;
RAM_Z80CALL_MD	EQU	STACK
RAM_Z80CALL_P1	EQU	RAM_Z80CALL_MD+1
RAM_Z80CALL_P2	EQU	RAM_Z80CALL_P1+1
RAM_Z80CALL_END	EQU	RAM_Z80CALL_P2+1


RAM_SYSREG	EQU	RAM_Z80CALL_END+1	; Beginn der Datentabelle am Ende des Stack (Stack
						; zaehlt ja nach unten)

RAM_ZEIT_ZAE1	EQU	RAM_SYSREG+1		; Zeitkonstanten fuer INT_INIT_RD in ITPBAS.INC
RAM_ZEIT_ZAE2	EQU	RAM_ZEIT_ZAE1+1

RAM_AKT_CON	EQU	RAM_ZEIT_ZAE2+1		; aktiver Connector

RAM_CON_TAB	EQU	RAM_AKT_CON+1		; Tabelle fuer aktuellen Datenstand der Connectoren (1-5)

RAM_ITP2_IWX	EQU	RAM_CON_TAB+5		; Tabelle fuer Daten der Ports (5Bytes)

RAM_CON_CONOUT	EQU	RAM_ITP2_IWX+5		; Connector fuer CONOUT (1.Terminal)
RAM_CON_CONOUT2	EQU	RAM_CON_CONOUT+1	; Connector fuer CONOUT2 (2.Terminal)
RAM_CON_CONIN	EQU	RAM_CON_CONOUT2+1	; Connector fuer CONIN (Keyboard)
RAM_CON_DISK	EQU	RAM_CON_CONIN+1		; Connector fuer DISK (HD, Floppy, RAMFLOPPY)
RAM_CON_DISK2	EQU	RAM_CON_DISK+1		; Connector fuer DISK2 (HD, Floppy, RAMFLOPPY)
RAM_CON_BOOT	EQU	RAM_CON_DISK2+1		; Connector fuer BOOT-Datei
RAM_CON_LIST	EQU	RAM_CON_BOOT+1		; Connector fuer LIST (Drucker)


























